BruteForceCollection class

Inheritance

Constructors

BruteForceCollection({required dynamic name, required dynamic repository, required dynamic dimension, required dynamic metric})

Properties

dimension int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
metric Metric
finalinherited
name String
finalinherited
repository Repository
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count() Future<int>
inherited
delete({required String id}) Future<void>
inherited
dispose() Future<void>
inherited
find({required List<double> vector, int limit = 10}) Future<List<Document>>
override
get({required String id}) Future<Document?>
inherited
getDocuments({required List<String> ids}) Future<List<Document>>
inherited
insert({required String id, required List<double> vector, required String text, Map<String, dynamic>? metadata}) Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited