Collection class abstract

Implementers

Constructors

Collection(String name, Repository repository, int dimension, Metric metric)

Properties

dimension int
final
hashCode int
The hash code for this object.
no setterinherited
metric Metric
final
name String
final
repository Repository
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count() Future<int>
delete({required String id}) Future<void>
dispose() Future<void>
find({required List<double> vector, int limit = 10}) Future<List<Document>>
get({required String id}) Future<Document?>
getDocuments({required List<String> ids}) Future<List<Document>>
insert({required String id, required List<double> vector, required String text, Map<String, dynamic>? metadata}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited