DbRepository class
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
count(
) → Future< int> -
override
-
delete(
{required String id}) → Future< void> -
override
-
dispose(
) → Future< void> -
override
-
getDocuments(
{required List< String> ids}) → Future<List< Document> > -
override
-
getVectors(
) → Future< List< Vector> > -
override
-
insert(
{required String id, required Uint8List vector, required String text, Map< String, dynamic> ? metadata}) → Future<void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited